/* arequipa.h - AREQUIPA support functions */
 
/* Written 1996-1998 by Jean-Michel Pittet and Werner Almesberger,
			EPFL-LRC/ICA */
 

#ifndef _AREQUIPA_H
#define _AREQUIPA_H

#include <atm.h>

int arequipa_preset(int sd,const struct sockaddr_atmsvc *addr,
  const struct atm_qos *qos);
int arequipa_expect(int sd,int on);
int arequipa_renegotiate(int sd,const struct atm_qos *qos);
int arequipa_close(int sd);

#endif
